@@ -115,6 +115,10 @@ data DevelOpts = DevelOpts
       , proxyTimeout :: Int
       , useReverseProxy :: Bool
       , terminateWith :: DevelTermOpt
+
+      -- Support for GHC_PACKAGE_PATH wrapping
+      , develConfigOpts :: [String]
+      , develEnv :: Maybe [(String, String)]
       } deriving (Show, Eq)
 
 getBuildDir :: DevelOpts -> String
@@ -191,7 +195,10 @@ reverseProxy opts iappPort = do
     putStrLn $ "If you wish to test https capabilities, you should set the following variable:"
     putStrLn $ "  export APPROOT=https://127.0.0.1:" ++ show (develTlsPort opts)
     putStrLn ""
-    loop (race_ httpProxy httpsProxy) `Ex.onException` exitFailure
+    loop (race_ httpProxy httpsProxy) `Ex.catch` \e -> do
+        print (e :: Ex.SomeException)
+        exitFailure
+        Ex.throwIO e -- heh, just for good measure
   where
     loop proxies = forever $ do
         void proxies
@@ -350,8 +357,8 @@ configure opts extraArgs =
                                  , "--with-ghc=yesod-ghc-wrapper"
                                  , "--with-ar=yesod-ar-wrapper"
                                  , "--with-hc-pkg=ghc-pkg"
-                                 ] ++ extraArgs
-               )
+                                 ] ++ develConfigOpts opts ++ extraArgs
+               ) { env = develEnv opts }
 
 removeFileIfExists :: FilePath -> IO ()
 removeFileIfExists file = removeFile file `Ex.catch` handler
@@ -385,6 +392,8 @@ rebuildCabal :: DevelOpts -> IO Bool
 rebuildCabal opts = do
   putStrLn $ "Rebuilding application... (using " ++ cabalProgram opts ++ ")"
   checkExit =<< createProcess (proc (cabalProgram opts) args)
+        { env = develEnv opts
+        }
     where
       args | verbose opts = [ "build" ]
            | otherwise    = [ "build", "-v0" ]
